@@ -243,7 +243,7 @@
 
 #define HAVE_LIBUDEV_H 1
 /* #undef HAVE_LIBSAMPLERATE_H */
-#define HAVE_LIBDECOR_H 1
+/* #undef HAVE_LIBDECOR_H */
 
 /* #undef HAVE_D3D_H */
 /* #undef HAVE_D3D11_H */
@@ -316,7 +316,7 @@
 /* #undef SDL_AUDIO_DRIVER_PAUDIO */
 #define SDL_AUDIO_DRIVER_PIPEWIRE 1
 /* #undef SDL_AUDIO_DRIVER_PIPEWIRE_DYNAMIC */
-/* #undef SDL_AUDIO_DRIVER_PULSEAUDIO */
+#define SDL_AUDIO_DRIVER_PULSEAUDIO 1
 /* #undef SDL_AUDIO_DRIVER_PULSEAUDIO_DYNAMIC */
 /* #undef SDL_AUDIO_DRIVER_QSA */
 /* #undef SDL_AUDIO_DRIVER_SNDIO */
@@ -414,7 +414,7 @@
 #define SDL_VIDEO_DRIVER_OFFSCREEN 1
 /* #undef SDL_VIDEO_DRIVER_WINDOWS */
 /* #undef SDL_VIDEO_DRIVER_WINRT */
-#define SDL_VIDEO_DRIVER_WAYLAND 1
+/* #undef SDL_VIDEO_DRIVER_WAYLAND */
 /* #undef SDL_VIDEO_DRIVER_RPI */
 /* #undef SDL_VIDEO_DRIVER_VIVANTE */
 /* #undef SDL_VIDEO_DRIVER_VIVANTE_VDK */
@@ -428,7 +428,7 @@
 /* #undef SDL_VIDEO_DRIVER_KMSDRM_DYNAMIC */
 /* #undef SDL_VIDEO_DRIVER_KMSDRM_DYNAMIC_GBM */
 
-#define SDL_VIDEO_DRIVER_WAYLAND_QT_TOUCH 1
+/* #undef SDL_VIDEO_DRIVER_WAYLAND_QT_TOUCH */
 /* #undef SDL_VIDEO_DRIVER_WAYLAND_DYNAMIC */
 /* #undef SDL_VIDEO_DRIVER_WAYLAND_DYNAMIC_EGL */
 /* #undef SDL_VIDEO_DRIVER_WAYLAND_DYNAMIC_CURSOR */
@@ -543,7 +543,7 @@
 /* #undef SDL_VIDEO_VITA_PVR */
 /* #undef SDL_VIDEO_VITA_PVR_OGL */
 
-#define SDL_HAVE_LIBDECOR_GET_MIN_MAX 1
+/* #undef SDL_HAVE_LIBDECOR_GET_MIN_MAX */
 
 #if !defined(HAVE_STDINT_H) && !defined(_STDINT_H_)
 /* Most everything except Visual Studio 2008 and earlier has stdint.h now */
